#ifndef STAN_MATH_PRIM_SCAL_FUN_INV_HPP
#define STAN_MATH_PRIM_SCAL_FUN_INV_HPP

namespace stan {
  namespace math {

    inline double inv(double x) {
      return 1.0 / x;
    }

  }
}

#endif
